.. _spkg_beautifulsoup4:

beautifulsoup4: Screen-scraping library
=======================================

Description
-----------

Screen-scraping library

License
-------

MIT License

Upstream Contact
----------------

https://pypi.org/project/beautifulsoup4/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_pip`
- :ref:`spkg_soupsieve`

Version Information
-------------------

package-version.txt::

    4.12.3

version_requirements.txt::

    beautifulsoup4

See https://repology.org/project/python:beautifulsoup4/versions

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install beautifulsoup4

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i beautifulsoup4

.. tab:: Alpine:

   .. CODE-BLOCK:: bash

       $ apk add py3-beautifulsoup4

.. tab:: Arch Linux:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S python-beautifulsoup4

.. tab:: conda-forge:

   .. CODE-BLOCK:: bash

       $ conda install beautifulsoup4

.. tab:: Debian/Ubuntu:

   .. CODE-BLOCK:: bash

       $ sudo apt-get install python3-bs4

.. tab:: Fedora/Redhat/CentOS:

   .. CODE-BLOCK:: bash

       $ sudo dnf install python3-beautifulsoup4

.. tab:: Gentoo Linux:

   .. CODE-BLOCK:: bash

       $ sudo emerge dev-python/beautifulsoup4

.. tab:: MacPorts:

   .. CODE-BLOCK:: bash

       $ sudo port install py-beautifulsoup4

.. tab:: openSUSE:

   .. CODE-BLOCK:: bash

       $ sudo zypper install python-beautifulsoup4

.. tab:: Void Linux:

   .. CODE-BLOCK:: bash

       $ sudo xbps-install python3-BeautifulSoup4


If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then 
``./configure`` will check if the system package can be used.
